# PyFlowery

[<img alt="Actions Status" src="https://c.csw.im/cswimr/pyflowery/badges/workflows/actions.yaml/badge.svg?style=plastic">](https://c.csw.im/cswimr/pyflowery/actions?workflow=actions.yaml)
[<img alt="Documentation" src="https://app.readthedocs.org/projects/pyflowery/badge/?version=stable&style=flat">](https://pyflowery.csw.im)
[<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/pyflowery?style=plastic">](https://pypi.org/project/pyflowery/)
[<img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/pyflowery?style=plastic">](https://pypi.org/project/pyflowery/)
[<img alt="PyPI - License" src="https://img.shields.io/pypi/l/pyflowery?style=plastic">](https://c.csw.im/cswimr/pyflowery/src/branch/main/LICENSE/)  
A simple async Python API wrapper for the [Flowery API](https://flowery.pw/about). See documentation [here](https://pyflowery.csw.im).
